@@ -1,8 +1,8 @@
 test_that("continuous fill scales are created", {
   for (palette in academic_colour_palette_names()) {
     function_value <- scale_fill_academic_c(palette)
-    colours <- academic_colour_palette(palette)
-    expected_value <- ggplot2::scale_fill_gradientn(colours = colours)
+    palette <- academic_colour_palette(palette)
+    expected_value <- ggplot2::scale_fill_gradientn(colours = palette)
     expect_equal(
       function_value,
       expected_value
@@ -21,8 +21,12 @@ test_that("discrete fill scales are created", {
       scale_name = paste0("AcademicTheme: ", palette_name)
     )
     expect_equal(
-      function_value,
-      expected_value
+      .subset2(function_value, "palette"),
+      .subset2(expected_value, "palette")
+    )
+    expect_equal(
+      function_value$aesthetics,
+      expected_value$aesthetics,
     )
   }
 })
